.. configurator documentation master file, created by
   sphinx-quickstart on Tue May  2 14:29:56 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

API
===

.. toctree::

   pydecor


.. include:: ../README.rst

CHANGELOG
=========

.. include:: ../CHANGELOG.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
